@@ -5,11 +5,9 @@
 extern "C" {
 #endif
 
-#include <string.h>
-
 /* General information functions */
-char * __WINAPI explain(lprec *lp, char *format, ...);
-void __WINAPI report(lprec *lp, int level, char *format, ...);
+char * __VACALL explain(lprec *lp, char *format, ...);
+void __VACALL report(lprec *lp, int level, char *format, ...);
 
 /* Prototypes for debugging and general data dumps */
 void debug_print(lprec *lp, char *format, ...);
@@ -19,6 +17,7 @@ void blockWriteLREAL(FILE *output, char *label, LREAL *vector, int first, int la
 void blockWriteAMAT(FILE *output, const char *label, lprec* lp, int first, int last);
 void blockWriteBMAT(FILE *output, const char *label, lprec* lp, int first, int last);
 
+
 /* Model reporting headers */
 void REPORT_objective(lprec *lp);
 void REPORT_solution(lprec *lp, int columns);
@@ -27,14 +26,17 @@ void REPORT_duals(lprec *lp);
 void REPORT_extended(lprec *lp);
 
 /* Other rarely used, but sometimes extremely useful reports */
+void REPORT_constraintinfo(lprec *lp, char *datainfo);
 void REPORT_modelinfo(lprec *lp, MYBOOL doName, char *datainfo);
 void REPORT_lp(lprec *lp);
 MYBOOL REPORT_tableau(lprec *lp);
 void REPORT_scales(lprec *lp);
 MYBOOL REPORT_debugdump(lprec *lp, char *filename, MYBOOL livedata);
+MYBOOL REPORT_mat_mmsave(lprec *lp, char *filename, int *colndx, MYBOOL includeOF, char *infotext);
 
 #ifdef __cplusplus
  }
 #endif
 
 #endif /* HEADER_lp_report */
+
